==> rust-process-viewer_0.4.12.orig.tar.gz: process_viewer-0.4.12/README.md <==
# process-viewer [![Build Status](https://travis-ci.org/GuillaumeGomez/process-viewer.png?branch=master)](https://travis-ci.org/GuillaumeGomez/process-viewer)
A process viewer GUI in rust. It provides current status of your processes (cpu and memory usage) and your system (usage of every core and of your RAM, and the temperature of your components if this information is available).

It can be run on the following platforms:

 * Linux
 * Raspberry
 * Mac OSX
 * Windows (for cross-compilation to Windows, you can give a try to https://hub.docker.com/r/etrombly/rust-crosscompile)

Please run it in release mode to have good performance:

```bash
cargo run --release
```

or to install it as binary

```bash
cargo install process_viewer
```

### Building/running on Linux, MacOS

Running ```process-viewer``` on Gnome-based Ubuntu (>=17.10) should work out of the box.  
For Debian, Fedora and MacOS refer to the [gtk-rs installation guide](http://gtk-rs.org/docs/requirements.html).

### Bulding on Ubuntu-based Distros

```bash
sudo apt install -y libgtk-3-dev
```

### Building/running on Windows

You'll need to follow the [GTK installation guide](https://www.gtk.org/docs/installations/windows/). If you still have issues to run the generated binary, just copy the `.dll`s into the executable's folder.

### Running on Raspberry

It'll be difficult to build on Raspberry pi directly. A good way-around is to be build on Linux before sending it to your Raspberry pi:

```bash
rustup target add armv7-unknown-linux-gnueabihf
cargo build --target=armv7-unknown-linux-gnueabihf
```

## Donations

If you appreciate my work and want to support me, you can do it here:

[![Become a patron](https://c5.patreon.com/external/logo/become_a_patron_button.png)](https://www.patreon.com/GuillaumeGomez)

## Screenshots

![screenshot](http://guillaume-gomez.fr/image/screen3.png)
![screenshot](http://guillaume-gomez.fr/blog/images/new-graph-color.png)

==> rust-process-viewer_0.5.9.orig.tar.gz: process_viewer-0.5.9/README.md <==
# process-viewer [![Build Status](https://travis-ci.org/GuillaumeGomez/process-viewer.png?branch=master)](https://travis-ci.org/GuillaumeGomez/process-viewer)
A process viewer GUI in rust. It provides current status of your processes (cpu and memory usage) and your system (usage of every core and of your RAM, and the temperature of your components if this information is available).

It can be run on the following platforms:

 * Linux
 * Raspberry
 * macOS
 * FreeBSD
 * Windows (for cross-compilation to Windows, you can give a try to https://hub.docker.com/r/etrombly/rust-crosscompile)

Please run it in release mode to have good performance:

```bash
cargo run --release
```

or to install it as binary

```bash
cargo install process_viewer
```

### Building/running on Linux, MacOS

Take a look at the [gtk-rs installation guide](https://gtk-rs.org/gtk4-rs/stable/latest/book/installation.html) to know how install GTK dependencies.

### Running on Raspberry

It'll be difficult to build on Raspberry pi directly. A good way-around is to be build on Linux before sending it to your Raspberry pi:

```bash
rustup target add armv7-unknown-linux-gnueabihf
cargo build --target=armv7-unknown-linux-gnueabihf
```

## Donations

If you appreciate my work and want to support me, you can do it here:

[![Become a patron](https://c5.patreon.com/external/logo/become_a_patron_button.png)](https://www.patreon.com/GuillaumeGomez)

## Screenshots

![screenshot](http://guillaume-gomez.fr/image/process-viewer-screen1.png)
![screenshot](http://guillaume-gomez.fr/image/process-viewer-screen2.png)
